'use strict';

Object.defineProperty(exports, "__esModule", {
	value: true
});

var _slicedToArray2 = require('babel-runtime/helpers/slicedToArray');

var _slicedToArray3 = _interopRequireDefault(_slicedToArray2);

var _toConsumableArray2 = require('babel-runtime/helpers/toConsumableArray');

var _toConsumableArray3 = _interopRequireDefault(_toConsumableArray2);

exports.default = getForcedLeadingFn;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Get forced leading for rule
 * @param {object} rule to parse
 * @return {fn} transform function applying the leading
 */
function getForcedLeadingFn(rule) {
	var noop = function noop(input) {
		return input;
	};
	var remove = function remove(input) {
		var fragments = input.split('\n');
		return fragments[0] === '' ? fragments.slice(1).join('\n') : input;
	};
	var lead = function lead(input) {
		var fragments = input.split('\n');
		return fragments[0] === '' ? input : [''].concat((0, _toConsumableArray3.default)(fragments)).join('\n');
	};

	if (!rule) {
		return noop;
	}

	var leading = getForcedLeading(rule);

	if (leading === null) {
		return noop;
	}

	return leading ? lead : remove;
}

/**
 * Get forced leading for rule
 * @param {object} rule to parse
 * @return {boolean|null} transform function applying the leading
 */
function getForcedLeading(rule) {
	if (!rule) {
		return null;
	}

	var _rule = (0, _slicedToArray3.default)(rule, 2),
	    _rule$ = (0, _slicedToArray3.default)(_rule[1], 2),
	    severity = _rule$[0],
	    applicable = _rule$[1];

	var negated = applicable === 'never';

	if (severity === 0) {
		return null;
	}

	return !negated;
}
module.exports = exports['default'];
//# sourceMappingURL=get-forced-leading-fn.js.map